summaryrefslogtreecommitdiffstats
path: root/example/example_factory.cc
diff options
context:
space:
mode:
Diffstat (limited to 'example/example_factory.cc')
-rw-r--r--example/example_factory.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/example/example_factory.cc b/example/example_factory.cc
index eaba7ee4..ebba090d 100644
--- a/example/example_factory.cc
+++ b/example/example_factory.cc
@@ -44,14 +44,14 @@ ExampleFactory::~ExampleFactory()
s_global = 0L;
}
-KParts::Part* ExampleFactory::createPartObject( TQWidget *tqparentWidget, const char *widgetName, TQObject* tqparent, const char* name, const char* classname, const TQStringList & )
+KParts::Part* ExampleFactory::createPartObject( TQWidget *parentWidget, const char *widgetName, TQObject* tqparent, const char* name, const char* classname, const TQStringList & )
{
// If classname is "KoDocument", our host is a koffice application
// otherwise, the host wants us as a simple part, so switch to readonly and single view.
bool bWantKoDocument = ( strcmp( classname, "KoDocument" ) == 0 );
- // tqparentWidget and widgetName are used by KoDocument for the "readonly+singleView" case.
- ExamplePart *part = new ExamplePart( tqparentWidget, widgetName, tqparent, name, !bWantKoDocument );
+ // parentWidget and widgetName are used by KoDocument for the "readonly+singleView" case.
+ ExamplePart *part = new ExamplePart( parentWidget, widgetName, tqparent, name, !bWantKoDocument );
if ( !bWantKoDocument )
part->setReadWrite( false );